body {
	padding:50px;
	background-color: #A0A0A0;
	font-family:Georgia,"Times New Roman","Bitstream Charter",Times,serif;
	color:#093E56;
}

h1 {
	font-style:italic;
	text-shadow: 1px 2px 2px #aaa;
	font-weight:normal;
}

a {
   text-decoration: none;
   padding: 0 1ex 0 1ex;
}

a img {
    border: none;
}

.entry a , .entry input {
	outline:none;
    font-size: 21pt;
    color: #557;
}

.sortable {
    list-style-type: none;
}

.selected {
    border-radius: 1em;
    -moz-border-radius: 1em;
    background-image: -moz-linear-gradient(top, #91be15, #84b710 27px, #7ab200 27px, #86bb08);
    background-image: -webkit-gradient(linear, left bottom, right top, from(#fa0), color-stop(0.2, #fa0), color-stop(0.5, rgba(255,255,255, 0)));
}

.x_permissions_grp {
    background: #520;
    padding: 1em;
    width: 25em;
    border-radius: 1em;
    -moz-border-radius: 1em;
    color: #bbc;
}
.x_permissions_grp:hover {
    -moz-box-shadow: 10px 10px 5px #444;
    -webkit-box-shadow: 3px 1px 5px #444;
    box-shadow: 10px 10px 5px #444;
}
.x_permissions_grp span.toggler:hover {
    color: #520;
}
.x_permissions_grp span.toggler {
    border-radius: 1ex;
    -moz-border-radius: 1ex;
}

.x_permissions_grp:before {
    content:"Permissions:";
   font-weight: bold;
}

label.autoform {
    display: block;
    margin-top: 1ex;
    padding: 0 1ex 0 0;
}

#login_form {
    margin-bottom: 2em;
}

fieldset {
    border: solid 2px #bbc;
    margin-top: 1em;
    border-radius: 3em 10em 10em 3em;
    -moz-border-radius: 3em 10em 10em 3em;
}

.buttons {
    margin: 1ex auto;
    text-align: left;
}

.auto_edit_form {
    width: 80%;
    margin: 1em auto 0 auto;
    border: solid 2px black
    border-radius: 3em 10em 10em 3em;
    -moz-border-radius: 3em 10em 10em 3em;
}

div.editable {
    flush: left;
}

form input , div.input input , div.input textarea {
    margin: 0 0 0.7ex 0;
    border: solid 2px #fff;
    -webkit-border-radius: 1em;
    -moz-border-radius: 1em;
    border-radius: 1em;
}

form input:focus , div.input input:focus , div.input:focus textarea:focus {
    border: solid 2px #ff0;
}


div.input input[type="file"] {
    border: none;
}

input:hover , textarea:hover {
    background: #be8;
    -moz-box-shadow: 10px 10px 5px #444;
    -webkit-box-shadow: 3px 1px 5px #444;
    box-shadow: 10px 10px 5px #444;
}

div.editable span.label:hover {
    background: #be8;
    -moz-box-shadow: 10px 10px 5px #444;
    -webkit-box-shadow: 3px 1px 5px #444;
    box-shadow: 10px 10px 5px #444;
}

label > img {
    margin-bottom: -10px;
}

a {
    text-decoration: none;
    padding: 0 1ex 0 1ex;
}

a:hover {
    background: #dde;
    text-decoration: none;
    color: black;
    -moz-box-shadow: 10px 10px 5px #444;
    -webkit-box-shadow: 0px 2px 5px #444;
    box-shadow: 10px 10px 5px #444;
    border-radius: 3px;
    -moz-border-radius: 3px;
}

.error_message {
    font-size: 300%;
    color: #a55;
}

.toggler {
    cursor: pointer;
}

.icon {
    width: 32px;
    margin-right: 1ex;
    margin-bottom: -8px;
}
